hotspot/test/runtime/modules/JVMAddModulePackage.java
changeset 43446 4f9ac7ab99d9
parent 42307 cefc81dc1d52
child 43665 4bb003cad9b9
--- a/hotspot/test/runtime/modules/JVMAddModulePackage.java	Thu Jan 12 19:34:29 2017 +0000
+++ b/hotspot/test/runtime/modules/JVMAddModulePackage.java	Fri Jan 13 07:19:03 2017 -0500
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -84,11 +84,11 @@
             // Expected
         }
 
         // Existing package, expect an IAE
         try {
             ModuleHelper.AddModulePackage(module1, "yourpackage");
-            throw new RuntimeException("Failed to get the expected IAE");
-        } catch(IllegalArgumentException e) {
+            throw new RuntimeException("Failed to get the expected ISE");
+        } catch(IllegalStateException e) {
             // Expected
         }
@@ -84,11 +84,11 @@
         }
 
-        // Existing package, expect an IAE
+        // Existing package, expect an ISE
         try {
             ModuleHelper.AddModulePackage(module1, "yourpackage");